use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Anwar
Bruner
Collection
Cookbook
Cursor
DateTime
David
Document
Golden
Meerkat
MeerkatDateTime
Mohammad
MongoDBx
Moosey
MyModel
Role
Todd
Tutorial
Types
centric
dagolden
datetime
datetimes
lib
mapper
meerkat
mohammad
ness
synced
tbruner
todd
